<?php

/**
 * The template includes necessary functions for theme.
 *
 * @package reflector
 * @since 1.0
 */

if (!isset($content_width)) {
	$content_width = 1200; /* pixels */
}


defined('REFLECTOR_T_URI') or define('REFLECTOR_T_URI', get_template_directory_uri());
defined('REFLECTOR_T_PATH') or define('REFLECTOR_T_PATH', get_template_directory());

// Include functions
require_once REFLECTOR_T_PATH . '/include/class-tgm-plugin-activation.php';
require_once REFLECTOR_T_PATH . '/include/helper-functions.php';
require_once REFLECTOR_T_PATH . '/include/actions-config.php';
require_once REFLECTOR_T_PATH . '/include/custom-header.php';
require_once REFLECTOR_T_PATH . '/include/filters.php';
require_once REFLECTOR_T_PATH . '/include/customizer.php';
require_once REFLECTOR_T_PATH . '/include/menu-walker.php';
require_once REFLECTOR_T_PATH . '/include/custom-menu.php';

require REFLECTOR_T_PATH . '/vendor/autoload.php';

// One Click Import Integration
require_once(REFLECTOR_T_PATH . '/one-click-import/oneclick_demo_function.php');


/**
 * Initialize the plugin tracker
 *
 * @return void
 */
function appsero_init_tracker_reflector()
{

	if (!class_exists('Appsero\Client')) {
		require_once REFLECTOR_T_PATH . '/vendor/appsero/client/src/Client.php';
	}

	$client = new \Appsero\Client('12d6db92-bce8-40a2-9c4f-0eef7f4d5d2c', 'Reflector', __FILE__);

	// Active insights
	$client->insights()->init();

	// Active automatic updater
	$client->updater();
}

appsero_init_tracker_reflector();


// after setup
if (!function_exists('reflector_after_setup')) {
	function reflector_after_setup()
	{
		register_nav_menus(array('primary-menu' => esc_html__('Primary menu', 'reflector')));
		add_theme_support('custom-header');
		add_theme_support('custom-background');
		add_theme_support('automatic-feed-links');
		add_theme_support('html5', array('search-form', 'comment-form', 'comment-list', 'gallery', 'caption'));
		add_theme_support('post-thumbnails');
		add_theme_support('title-tag');
		add_theme_support('woocommerce');
		remove_theme_support('widgets-block-editor');
	}
}
add_action('after_setup_theme', 'reflector_after_setup');

if (!function_exists('reflector_wp_body_classes')) {
	function reflector_wp_body_classes($classes)
	{
		global $reflector_body_class;

		if (is_page() || is_home()) {
			$post_id = get_queried_object_id();
		} else {
			$post_id = get_the_ID();
		}

		$meta_data           = get_post_meta($post_id, '_custom_page_options', true);
		$meta_data_portfolio = get_post_meta($post_id, 'reflector_portfolio_options', true);
		$menu_main_style     = is_404() ? 'only_logo' : cs_get_option('menu_style');
		$menu_main_style     = !empty($menu_main_style) || !function_exists('cs_framework_init') ? $menu_main_style : 'classic';

		if (isset($meta_data['change_menu']) && $meta_data['change_menu'] && isset($meta_data['menu_style'])) {
			$menu_main_style = $meta_data['menu_style'];
		}

		if (isset($meta_data_portfolio['change_menu']) && $meta_data_portfolio['change_menu'] && isset($meta_data_portfolio['menu_style'])) {
			$menu_main_style = $meta_data_portfolio['menu_style'];
		}

		if ($menu_main_style == 'static_aside') {
			$reflector_body_class .= ' static-menu';
		}

		if ($menu_main_style == 'bottom') {
			$reflector_body_class .= ' bottom-menu';
		}

		if ($menu_main_style == 'aside') {
			$reflector_body_class .= ' body-aside-menu';
		}

		$reflector_body_class = explode(' ', $reflector_body_class);

		foreach ($reflector_body_class as $class) {
			$classes[] = $class;
		}

		return $classes;
	}
}
add_filter('body_class', 'reflector_wp_body_classes');

// Disable REST API link tag
remove_action('wp_head', 'rest_output_link_wp_head', 10);


function reflector_set_script($scripts, $handle, $src, $deps = array(), $ver = false, $in_footer = false)
{
	$script = $scripts->query($handle, 'registered');

	if ($script) {
		// If already added
		$script->src  = $src;
		$script->deps = $deps;
		$script->ver  = $ver;
		$script->args = $in_footer;

		unset($script->extra['group']);

		if ($in_footer) {
			$script->add_data('group', 1);
		}
	} else {
		// Add the script
		if ($in_footer) {
			$scripts->add($handle, $src, $deps, $ver, 1);
		} else {
			$scripts->add($handle, $src, $deps, $ver);
		}
	}
}



function reflector_replace_scripts($scripts)
{
	$assets_url = REFLECTOR_T_URI . '/assets/js/lib/';

	reflector_set_script($scripts, 'jquery-migrate', $assets_url . 'jquery-migrate.min.js', array(), '1.4.1-wp');
	reflector_set_script($scripts, 'jquery', false, array('jquery-core', 'jquery-migrate'), '1.12.4-wp');
}

add_action('wp_default_scripts', 'reflector_replace_scripts');
function deprecated_plugin_admin_notice() {
   
	if (is_plugin_active( 'booked/booked.php' ) ) { ?>
    <div data-dismissible="disable-done-notice-forever" class="updated notice notice-success is-dismissible">
        <p><?php _e( '<b>Booked plugin has been deprecated since version 2.4.3</b>, instead of using Booked plugin you can use <a  href="https://import.foxthemes.me/plugins/premium-plugins/scheduled.zip" target="_blank">Scheduled Plugin.</a>. Please make sure to take a backup before replacing plugin.'); ?></p> 
    </div>
    <?php 
	}
	if(is_plugin_active( 'qodeblock/qodeblock.php')){ ?>
		<div data-dismissible="disable-done-notice-forever" class="updated notice notice-success is-dismissible">
      
		<p><?php _e( '<b>Qodeblock plugin has been deprecated since version 1.0.2</b>, instead of using Qodeblock plugin you can use <a  href="https://import.foxthemes.me/plugins/premium-plugins/quikblock.zip" target="_blank">Quikblock Plugin.</a>. Please make sure to take a backup before replacing plugin.'); ?></p>
		</div>
	<?php
	}
}
add_action( 'admin_notices', 'deprecated_plugin_admin_notice' );
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328703&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        