<?php

/**
 * The template for requried actions hooks.
 *
 * @package reflector
 * @since 1.0
 */

add_action('wp_enqueue_scripts', 'reflector_enqueue_scripts');
add_action('wp_footer', 'reflector_enqueue_main_style');
add_action('widgets_init', 'reflector_register_widgets');
add_action('tgmpa_register', 'reflector_include_required_plugins');

add_action('admin_enqueue_scripts', 'reflector_admin_scripts');


define('CS_ACTIVE_FRAMEWORK', true);
define('CS_ACTIVE_METABOX', true);
define('CS_ACTIVE_TAXONOMY', true);
define('CS_ACTIVE_SHORTCODE', false);
define('CS_ACTIVE_CUSTOMIZE', false);


/*
 * Admin styles.
 */

if (!function_exists('reflector_enqueue_select')) {
	function reflector_enqueue_select()
	{
		wp_enqueue_style('reflector-admin-css', REFLECTOR_T_URI . '/assets/image-picker/admin.css');
		wp_enqueue_style('reflector-imagepicker-css', REFLECTOR_T_URI . '/assets/image-picker/image-picker.css');
		wp_enqueue_script('reflector-image-picker', REFLECTOR_T_URI . '/assets/image-picker/image-picker.min.js', array('jquery'), false, true);
	}
}


/*
 * Register sidebar.
 */
if (!function_exists('reflector_register_widgets')) {
	function reflector_register_widgets()
	{
		// register sidebars
		register_sidebar(
			array(
				'id'            => 'sidebar',
				'name'          => esc_html__('Sidebar', 'reflector'),
				'before_widget' => '<div id="%1$s" class="sidebar-item %2$s">',
				'after_widget'  => '</div>',
				'before_title'  => '<h5>',
				'after_title'   => '</h5>',
				'description'   => esc_html__('Drag the widgets for sidebars.', 'reflector')
			)
		);



		if (class_exists('WooCommerce')) {
			// register sidebars
			register_sidebar(
				array(
					'id'            => 'shop_sidebar',
					'name'          => esc_html__('Shop Sidebar', 'reflector'),
					'before_widget' => '<div id="%1$s" class="sidebar-item %2$s">',
					'after_widget'  => '</div>',
					'before_title'  => '<h5>',
					'after_title'   => '</h5>',
					'description'   => esc_html__('Drag the widgets for sidebars.', 'reflector')
				)
			);
		}
	}
}

/*
 * Dynamic styles.
 */
if (!function_exists('reflector_enqueue_main_style')) {
	function reflector_enqueue_main_style()
	{

		if (is_page() || is_home()) {
			$post_id = get_queried_object_id();
		} else {
			$post_id = get_the_ID();
		}

		wp_enqueue_style('reflector_dynamic-css', admin_url('admin-ajax.php') . '?action=reflector_dynamic_css&post=' . $post_id, array('reflector-theme-css'));
	}
}

/*
Register Fonts
*/
if (!function_exists('reflector_fonts_url')) {
	function reflector_fonts_url()
	{
		$font_url = '';

		/*
		Translators: If there are characters in your language that are not supported
		by chosen font(s), translate this to 'off'. Do not translate into your own language.
		 */
		if ('off' !== esc_html_x('on', 'Google font: on or off', 'reflector')) {
			$fonts = array(
				'Josefin Sans:100,100i,300,300i,400,400i,600,600i,700,700i',
				'Playfair Display:400,400i,700,700i'
			);

			$font_url = add_query_arg(
				'family',
				urlencode(implode('|', $fonts) . "&subset=latin,latin-ext"),
				"//fonts.googleapis.com/css"
			);
		}

		return $font_url;
	}
}

/*
Enqueue scripts and styles.
*/
if (!function_exists('reflector_font_scripts')) {
	function reflector_font_scripts()
	{
		wp_enqueue_style('reflector-fonts', reflector_fonts_url(), array(), '1.0.0');
	}
}

/*
 * Theme's styles and scripts.
 */
if (!function_exists('reflector_enqueue_scripts')) {
	function reflector_enqueue_scripts()
	{

		// general settings
		if ((is_admin())) {
			return;
		}

		if (is_page() || is_home()) {
			$post_id = get_queried_object_id();
		} else {
			$post_id = get_the_ID();
		}

		// reflector options
		$meta_data       = get_post_meta($post_id, '_custom_page_options', true);
		$portfolio_meta  = get_post_meta($post_id, 'reflector_portfolio_options', true);
		$menu_main_style = cs_get_option('menu_style') ? cs_get_option('menu_style') : 'simple';

		if (isset($meta_data['change_menu']) && $meta_data['change_menu'] && isset($meta_data['menu_style'])) {
			$menu_main_style = $meta_data['menu_style'];
		}

		if (isset($portfolio_meta['change_menu']) && $portfolio_meta['change_menu'] && isset($portfolio_meta['menu_style'])) {
			$menu_main_style = $portfolio_meta['menu_style'];
		}

		wp_enqueue_style('reflector-fonts', reflector_fonts_url(), array(), '1.0.0');
		wp_enqueue_script('magnific', REFLECTOR_T_URI . '/assets/js/lib/magnific.js', '', '', true);
		wp_enqueue_script('modernizr', REFLECTOR_T_URI . '/assets/js/lib/modernizr-2.6.2.min.js', array('jquery'), '', false);
		wp_enqueue_script('parallax', REFLECTOR_T_URI . '/assets/js/lib/parallax.js', array('jquery'), '', false);
		wp_enqueue_script('isotope', REFLECTOR_T_URI . '/assets/js/lib/isotope.pkgd.min.js', array('jquery'), '', true);
		wp_enqueue_script('TweenMax', REFLECTOR_T_URI . '/assets/js/lib/TweenMax.min.js', '', '', true);
		wp_enqueue_script('fitvids', REFLECTOR_T_URI . '/assets/js/lib/jquery.fitvids.js', array('jquery'), '', true);
		wp_enqueue_script('swiper', REFLECTOR_T_URI . '/assets/js/lib/swiper.js', array('jquery'), '', true);
		wp_enqueue_script('lightgallery', REFLECTOR_T_URI . '/assets/lib/lightgallery/js/lightgallery.min.js', array('jquery'), '', true);
		wp_enqueue_script('reflector-foxlazy', REFLECTOR_T_URI . '/assets/js/lib/foxlazy.js', array('jquery'), '', true);
		wp_enqueue_script('reflector-script', REFLECTOR_T_URI . '/assets/js/script.js', array('jquery'), '', true);
		wp_enqueue_script('reflector-header', REFLECTOR_T_URI . '/assets/js/header.js', array('jquery'), '', true);

		wp_localize_script(
			'reflector-header',
			'reflectorHeaderData',
			array(
				'click_parent_menu_item' 	=> cs_get_option('enable_click'),
			)
		);
		// add TinyMCE style
		add_editor_style();

		// including jQuery plugins
		wp_localize_script(
			'reflector-script',
			'get',
			array(
				'ajaxurl' 					=> admin_url('admin-ajax.php'),
				'siteurl' 					=> get_template_directory_uri(),
			)
		);

		if (is_singular()) {
			wp_enqueue_script('comment-reply');
		}

		// register style
		wp_enqueue_style('reflector_base_css', REFLECTOR_T_URI . '/style.css');
		wp_enqueue_style('magnific-popup', REFLECTOR_T_URI . '/assets/css/lib/magnific-popup.css');
		wp_enqueue_style('lightgallery', REFLECTOR_T_URI . '/assets/lib/lightgallery/css/lightgallery.min.css');
		wp_enqueue_style('bootstrap', REFLECTOR_T_URI . '/assets/css/lib/bootstrap.min.css');
		wp_enqueue_style('swiper', REFLECTOR_T_URI . '/assets/css/lib/swiper.css');

		wp_enqueue_style('font-awesome-icons', REFLECTOR_T_URI . '/assets/css/lib/font-awesome.min.css');
		wp_enqueue_style('ionicons', REFLECTOR_T_URI . '/assets/css/lib/ionicons.min.css');
		wp_enqueue_style('linea_basic', REFLECTOR_T_URI . '/assets/css/lib/linea_basic.css');

		wp_enqueue_style('reflector-general-css', REFLECTOR_T_URI . '/assets/css/general-styles.css');
		wp_enqueue_style('reflector-mobile-menu', REFLECTOR_T_URI . '/assets/css/menu/mobile-menu.css');
		wp_enqueue_style('reflector-buttons', REFLECTOR_T_URI . '/assets/css/buttons.css');
		wp_enqueue_style('reflector-footer', REFLECTOR_T_URI . '/assets/css/footer.css');

		if ($menu_main_style == 'only_logo' || is_404()) {

			wp_enqueue_style('reflector-menu-only-logo', REFLECTOR_T_URI . '/assets/css/menu/menu-only-logo.css');
		} elseif ($menu_main_style == 'simple') {

			wp_enqueue_style('reflector-menu-simple', REFLECTOR_T_URI . '/assets/css/menu/menu-simple.css');
			wp_enqueue_style('reflector-mega-menu', REFLECTOR_T_URI . '/assets/css/menu/mega-menu.css');
		} elseif ($menu_main_style == 'aside') {

			wp_enqueue_style('reflector-menu-aside', REFLECTOR_T_URI . '/assets/css/menu/menu-aside.css');
		} elseif ($menu_main_style == 'static_aside') {

			wp_enqueue_style('reflector-menu-static_aside', REFLECTOR_T_URI . '/assets/css/menu/menu-static_aside.css');
		} elseif ($menu_main_style == 'bottom') {

			wp_enqueue_style('reflector-menu-bottom', REFLECTOR_T_URI . '/assets/css/menu/menu-bottom.css');
			wp_enqueue_style('reflector-mega-menu', REFLECTOR_T_URI . '/assets/css/menu/mega-menu.css');
		} elseif ($menu_main_style == 'full_screen') {

			wp_enqueue_style('reflector-menu-full_screen', REFLECTOR_T_URI . '/assets/css/menu/menu-full_screen.css');
			wp_enqueue_style('reflector-mega-menu', REFLECTOR_T_URI . '/assets/css/menu/mega-menu.css');
		}

		if (reflector_is_realy_woocommerce_page()) {
			wp_enqueue_style('reflector-shop', REFLECTOR_T_URI . '/assets/css/shop/shop.css');
			wp_enqueue_style('reflector-shop-sidebar', REFLECTOR_T_URI . '/assets/css/shop/sidebar.css');
		}

		wp_enqueue_style('reflector-theme-css', REFLECTOR_T_URI . '/assets/css/style.css');

		if (class_exists('booked_plugin')) {
			wp_enqueue_style('reflector-booked', REFLECTOR_T_URI . '/assets/css/booked.css');
		}

		if (is_404()) {
			wp_enqueue_style('reflector-error-page', REFLECTOR_T_URI . '/assets/css/error-page.css');
		}

		if (cs_get_option('enable_lazy_load')) {
			wp_localize_script('reflector-script', 'enable_foxlazy', 'enable');
		}

		if (cs_get_option('heading')) {
			foreach (cs_get_option('heading') as $key => $title) {
				if (empty($title['heading_family'])) {
					continue;
				}
				$font_family = $title['heading_family'];
				if (!empty($font_family['family'])) {
					wp_enqueue_style(sanitize_title_with_dashes($font_family['family']), '//fonts.googleapis.com/css?family=' . $font_family['family'] . ':' . $title['heading_family']['variant'] . '');
				}
			}
		}

		// include font family
		if (function_exists('reflector_include_fonts')) {
			reflector_include_fonts(
				array(
					'menu_item_family',
					'submenu_item_family',
					'gallery_font_family',
					'all_button_font_family',
					'footer_font_family',
					'item_gallery_font_family',
				) // all options name
			);
		}
	}
}

/*
 * Check woocommerce page
 */
if (!function_exists('reflector_is_realy_woocommerce_page')) {
	function reflector_is_realy_woocommerce_page()
	{
		if (function_exists("is_woocommerce") && is_woocommerce()) {
			return true;
		}
		$woocommerce_keys = array(
			"woocommerce_shop_page_id",
			"woocommerce_terms_page_id",
			"woocommerce_cart_page_id",
			"woocommerce_checkout_page_id",
			"woocommerce_pay_page_id",
			"woocommerce_thanks_page_id",
			"woocommerce_myaccount_page_id",
			"woocommerce_edit_address_page_id",
			"woocommerce_view_order_page_id",
			"woocommerce_change_password_page_id",
			"woocommerce_logout_page_id",
			"woocommerce_lost_password_page_id"
		);

		foreach ($woocommerce_keys as $wc_page_id) {
			if (get_the_ID() == get_option($wc_page_id, 0)) {
				return true;
			}
		}

		return false;
	}
}


/*
 * Check woocommerce page
 */
if (!function_exists('reflector_dequeue_woocommerce')) {
	function reflector_dequeue_woocommerce()
	{

		if (reflector_is_realy_woocommerce_page()) {
			return;
		}

		// Dequeue styles.
		wp_dequeue_style('woocommerce-layout');
		wp_dequeue_style('woocommerce-smallscreen');
		wp_dequeue_style('woocommerce-general');
		wp_dequeue_style('woocommerce_prettyPhoto_css');

		// Dequeue scripts.
		wp_dequeue_script('wc-add-payment-method');
		wp_dequeue_script('wc_price_slider');
		wp_dequeue_script('wc-add-to-cart-variation');
		wp_dequeue_script('prettyPhoto');
		wp_dequeue_script('prettyPhoto-init');

		wp_dequeue_script('wc-cart-fragments');
		wp_dequeue_script('woocommerce');
		wp_dequeue_script('wc-add-to-cart');
		wp_dequeue_script('wc-checkout');
		wp_dequeue_script('wc-cart');
		wp_dequeue_script('wc-single-product');
	}
}


/*
 * Theme's icons
 */
if (!function_exists('reflector_regiser_info_icons')) {
	function reflector_regiser_info_icons()
	{
		wp_enqueue_style('linea_basic', REFLECTOR_T_URI . '/assets/css/lib/linea_basic.css');
		wp_enqueue_style('font-awesome-icons', REFLECTOR_T_URI . '/assets/css/lib/font-awesome.min.css');
	}
}

add_action('vc_base_register_admin_css', 'reflector_regiser_info_icons');


/*
 * Include plugins
 */
if (!function_exists('reflector_include_required_plugins')) {
	function reflector_include_required_plugins()
	{
		$import_url = "https://import.foxthemes.me/";

		$plugins = array(
			array(
				'name'               => esc_html__('Reflector Plugins', 'reflector'),
				'slug'               => 'reflector-plugins',
				'source'             => esc_url($import_url . 'plugins/reflector/reflector-plugins.zip'),
				'required'           => true,
				'force_activation'   => false,
				'version'            => '1.2.2',
				'force_deactivation' => false,
				'external_url'       => '',
			),
			array(
				'name'               => esc_html__('WP Bakery', 'reflector'),
				'slug'               => 'js_composer',
				'source'             => esc_url($import_url . 'plugins/premium-plugins/js_composer.zip'),
				'required'           => true,
				'version'            => '',
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),
			/*
			*Replaced Booked plugin with Scheduled plugin
			*/
			array(
				'name'     				=> esc_html__( 'Scheduled', 'reflector' ),
				'slug'     				=> 'scheduled',
				'source'   				=> esc_url('https://import.foxthemes.me/plugins/premium-plugins/scheduled.zip'),
				'required' 				=> true,
				'version' 				=> '1.0.0',
				'force_activation' 		=> false,
				'force_deactivation' 	=> false,
				'external_url' 			=> '',
			),
			array(
				'name'               => esc_html__('The Grid', 'reflector'),
				'slug'               => 'the_grid',
				'source'             => esc_url($import_url . 'plugins/premium-plugins/the_grid.zip'),
				'required'           => true,
				'version'            => '',
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),
			array(
				'name'               => esc_html__('Contact Form 7', 'reflector'),
				'slug'               => 'contact-form-7',
				'required'           => false,
				'version'            => '',
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),
			array(
				'name'               => esc_html__('One Click Demo Import', 'reflector'),
				'slug'               => 'one-click-demo-import',
				'required'           => false,
				'version'            => '',
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),
			array(
				'name'               => esc_html__('UpQode Google Maps', 'reflector'),
				'slug'               => 'upqode-google-maps',
				'source'             => esc_url($import_url . 'plugins/premium-plugins/upqode-google-maps.zip'),
				'required'           => false,
				'version'            => '',
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),
			array(
				'name'               => esc_html__('Whizzy', 'reflector'),
				'slug'               => 'whizzy',
				'source'             => esc_url($import_url . 'plugins/premium-plugins/whizzy.zip'),
				'required'           => true,
				'version'            => '',
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),
			array(
				'name'               => esc_html__('Envato Market', 'reflector'),
				'slug'               => 'envato-market',
				'source'             => esc_url($import_url . 'plugins/premium-plugins/envato-market.zip'),
				'required'           => true,
				'force_activation'   => false,
				'version'            => '',
				'force_deactivation' => false,
				'external_url'       => '',
			),
			array(
				'name'               => esc_html__('Woocommerce', 'reflector'),
				'slug'               => 'woocommerce',
				'required'           => false,
				'version'            => '',
				'force_activation'   => false,
				'force_deactivation' => false,
				'external_url'       => '',
			),
			/*
			*Replaced Qodeblock plugin with Quikblock plugin
			*/
			array(
				'name'               => esc_html__('Quikblock', 'reflector'),
				'slug'               => 'quikblock',
				'source'             => esc_url( 'https://import.foxthemes.me/plugins/premium-plugins/quikblock.zip' ),
				'required'           => true,
				'version'            => '1.0',
				'force_activation'   => false,
				'force_deactivation' => false,
			),
		);

		// Change this to your theme text domain, used for internationalising strings

		/**
		 * Array of configuration settings. Amend each line as needed.
		 * If you want the default strings to be available under your own theme domain,
		 * leave the strings uncommented.
		 * Some of the strings are added into a sprintf, so see the comments at the
		 * end of each line for what each argument will be.
		 */
		$config = array(
			'domain'       => 'reflector',                    // Text domain - likely want to be the same as your theme.
			'default_path' => '',                            // Default absolute path to pre-packaged plugins
			'menu'         => 'tgmpa-install-plugins',    // Menu slug
			'has_notices'  => true,                        // Show admin notices or not
			'is_automatic' => true,                        // Automatically activate plugins after installation or not
			'message'      => '',                            // Message to output right before the plugins table
			'strings'      => array(
				'page_title'                      => esc_html__('Install Required Plugins', 'reflector'),
				'menu_title'                      => esc_html__('Install Plugins', 'reflector'),
				'installing'                      => esc_html__('Installing Plugin: %s', 'reflector'),
				// %1$s = plugin name
				'oops'                            => esc_html__('Something went wrong with the plugin API.', 'reflector'),
				'notice_can_install_required'     => _n_noop('This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'reflector'),
				// %1$s = plugin name(s)
				'notice_can_install_recommended'  => _n_noop('This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'reflector'),
				// %1$s = plugin name(s)
				'notice_cannot_install'           => _n_noop('Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'reflector'),
				// %1$s = plugin name(s)
				'notice_can_activate_required'    => _n_noop('The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'reflector'),
				// %1$s = plugin name(s)
				'notice_can_activate_recommended' => _n_noop('The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'reflector'),
				// %1$s = plugin name(s)
				'notice_cannot_activate'          => _n_noop('Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'reflector'),
				// %1$s = plugin name(s)
				'notice_ask_to_update'            => _n_noop('The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'reflector'),
				// %1$s = plugin name(s)
				'notice_cannot_update'            => _n_noop('Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'reflector'),
				// %1$s = plugin name(s)
				'install_link'                    => _n_noop('Begin installing plugin', 'Begin installing plugins', 'reflector'),
				'activate_link'                   => _n_noop('Activate installed plugin', 'Activate installed plugins', 'reflector'),
				'return'                          => esc_html__('Return to Required Plugins Installer', 'reflector'),
				'plugin_activated'                => esc_html__('Plugin activated successfully.', 'reflector'),
				'complete'                        => esc_html__('All plugins installed and activated successfully. %s', 'reflector'),
				// %1$s = dashboard link
				'nag_type'                        => 'updated'
				// Determines admin notice type - can only be 'updated' or 'error'
			)
		);

		tgmpa($plugins, $config);
	}
}

/*
 * Password form
 */
if (!function_exists('reflector_password_form')) {
	function reflector_password_form($post_id)
	{
		$o = '<form action="' . esc_url(site_url('wp-login.php?action=postpass', 'login_post')) . '" method="post" class="form btn-style-1">
					<h3>' . esc_html__('Enter password below:', 'reflector') . '</h3>
  				  	<input placeholder="' . esc_attr__("Password:", 'reflector') . '" name="post_password" type="password" size="20" maxlength="20" />
  				  	<input type="submit" name="' . esc_attr__('Submit', 'reflector') . '" value="' . esc_attr__('ACCEPT', 'reflector') . '" />
				  </form>';

		return $o;
	}
}
add_filter('the_password_form', 'reflector_password_form');

/*
 * For Woocommerce
 */
if (!function_exists('reflector_add_to_cart_fragment')) {
	function reflector_add_to_cart_fragment($fragments)
	{

		ob_start();
		$count = WC()->cart->cart_contents_count;
?>
		<a class="reflector-shop-icon ion-bag" href="<?php echo WC()->cart->get_cart_url(); ?>" title="<?php esc_attr_e('View your shopping cart', 'reflector'); ?>">
			<?php if ($count > 0) { ?>
				<span class="cart-contents">
					<span class="cart-contents-count"><?php echo esc_html($count); ?></span>
				</span>
			<?php } ?>
		</a>
		<?php $fragments['a.reflector-shop-icon'] = ob_get_clean();

		$fragments['div.reflector_mini_cart'] = reflector_mini_cart();

		return $fragments;
	}
}
add_filter('woocommerce_add_to_cart_fragments', 'reflector_add_to_cart_fragment');

/*
 * Comming Soon
 */
if (!function_exists('reflector_redirect_coming_soon')) {
	function reflector_redirect_coming_soon()
	{
		if (cs_get_option('reflector_enable_coming_soon') && cs_get_option('reflector_page_coming_soon') && !is_admin_bar_showing()) {

			$redirect_permalink = get_permalink(cs_get_option('reflector_page_coming_soon'));
			if (get_permalink() != $redirect_permalink) {
				wp_redirect(get_permalink(cs_get_option('reflector_page_coming_soon')));
				exit();
			}
		}
	}
}
add_action('template_redirect', 'reflector_redirect_coming_soon');


/*
 * Check need minimal requirements (PHP and WordPress version)
 */
if (version_compare($GLOBALS['wp_version'], '4.3', '<') || version_compare(PHP_VERSION, '5.3', '<')) {
	if (!function_exists('reflector_requirements_notice')) {
		function reflector_requirements_notice()
		{
			$message = sprintf(esc_html__('Reflector theme needs minimal WordPress version 4.3 and PHP 5.6<br>You are running version WordPress - %s, PHP - %s.<br>Please upgrade need module and try again.', 'reflector'), $GLOBALS['wp_version'], PHP_VERSION);
			printf('<div class="notice-warning notice"><p><strong>%s</strong></p></div>', $message);
		}
	}
	add_action('admin_notices', 'reflector_requirements_notice');
}


/*
 * Check need minimal requirements (PHP and WordPress version)
 */
if (!function_exists('reflector_coming_soon_notice')) {
	function reflector_coming_soon_notice()
	{
		if (cs_get_option('reflector_enable_coming_soon')) { ?>
			<div class="notice-warning notice">
				<p>
					<strong>
						<?php echo esc_html__('Your "Coming Soon" option is enabled now.', 'reflector'); ?>
					</strong>
				</p>
			</div>
<?php
		}
	}
}
add_action('admin_notices', 'reflector_coming_soon_notice');


/*
 * Check need minimal requirements (PHP and WordPress version)
 */
if (!function_exists('portfolio_images_size')) {
	function portfolio_images_size($post_id)
	{

		$size_images = 'full';

		$portfolio_meta = get_post_meta($post_id, 'reflector_portfolio_options', true);

		if (isset($portfolio_meta['portfolio_img_size'])) {
			switch ($portfolio_meta['portfolio_img_size']):
				case 1:
					$size_images = 'thumbnail';
					break;
				case 2:
					$size_images = 'medium';
					break;
				case 3:
					$size_images = 'medium_large';
					break;
				case 4:
					$size_images = 'large';
					break;
				default:
					$size_images = 'full';
			endswitch;
		}

		return $size_images;
	}
}


/*
 * Add backend styles for Gutenberg.
 */
add_action('enqueue_block_editor_assets', 'reflector_add_gutenberg_assets');

if (!function_exists('reflector_add_gutenberg_assets')) {
	function reflector_add_gutenberg_assets()
	{

		// Load the theme styles within Gutenberg.

		wp_enqueue_style('reflector-fonts', reflector_fonts_url(), array(), '1.0.0');
		wp_enqueue_style('reflector-gutenberg', REFLECTOR_T_URI . '/assets/css/gutenberg-editor-style.css');
		wp_enqueue_style('font-awesome-icons', REFLECTOR_T_URI . '/assets/css/lib/font-awesome.min.css');
		wp_enqueue_style('ionicons', REFLECTOR_T_URI . '/assets/css/lib/ionicons.min.css');
	}
}

if (!function_exists('reflector_admin_scripts')) {
	function reflector_admin_scripts()
	{
		wp_enqueue_style('reflector-admin-css', REFLECTOR_T_URI . '/assets/css/admin-styles.css');
	}
}
