<?php
/**
 * Requried functions for theme backend.
 *
 * @package reflector
 * @subpackage Template
 */

// cs framework missing
if ( !function_exists('cs_get_option') ) {
    function cs_get_option() {
        return '';
    }

    function cs_get_customize_option() {
        return '';
    }
}

if ( !function_exists('reflector_add_default_cs_websafe_fonts') ) {
    function reflector_add_default_cs_websafe_fonts($params) {
        return array_merge(array(''), $params);
    }
}
add_filter('cs_websafe_fonts', 'reflector_add_default_cs_websafe_fonts');

/**
 * Сustom reflector menu.
 */
if ( !function_exists('reflector_custom_menu') ) {
    function reflector_custom_menu() {
        $walker         = new reflector_Menu_Walker();
        $args           = array('container' => '', 'walker' => $walker);
        $meta_data      = get_post_meta(get_the_ID(), '_custom_page_options', true);
        $portfolio_data = get_post_meta(get_the_ID(), 'reflector_portfolio_options', true);

        $current_menu = 'default';
        $current_menu = isset($meta_data['page_menu']) ? $meta_data['page_menu'] : $current_menu;
        $current_menu = isset($portfolio_data['page_menu']) ? $portfolio_data['page_menu'] : $current_menu;

        if ( $current_menu != 'none' ) {
            if ( $current_menu == 'default' ) {
                if ( has_nav_menu('primary-menu') ) {
                    $args['theme_location'] = 'primary-menu';
                    wp_nav_menu($args);
                } else {
                    echo '<span class="no-menu primary-no-menu">' . esc_html__('Please register Top Navigation from', 'reflector') . ' <a href="' . esc_url(admin_url('nav-menus.php')) . '" target="_blank">' . esc_html__('Appearance &gt; Menus', 'reflector') . '</a></span>';
                }
            } else {
                $args['menu'] = $current_menu;
                wp_nav_menu($args);
            }
        }
    }
}

/**
 * Сustom reflector menu list.
 */
if ( !function_exists('reflector_get_menus') ) {
    function reflector_get_menus() {
        $menus = get_terms('nav_menu', array('hide_empty' => true));
        $array = array('default' => 'Default', 'none' => 'None');
        foreach ( $menus as $menu ) {
            $array[$menu->slug] = $menu->name;
        }

        return $array;
    }
}


/**
 *
 * Get first "url" from post content or string
 *
 */
if ( !function_exists('reflector_get_first_url_from_string') ) {
    function reflector_get_first_url_from_string($string) {
        $pattern = "/^\b(?:(?:https?|ftp):\/\/)[-a-z0-9+&@#\/%?=~_|!:,.;]*[-a-z0-9+&@#\/%=~_|]/i";
        preg_match($pattern, $string, $link);

        return (!empty($link[0])) ? $link[0] : false;
    }
}

/**
 *
 * Custom Regular Expression
 *
 */
if ( !function_exists('reflector_get_shortcode_regex') ) {
    function reflector_get_shortcode_regex($tagregexp = '') {
        // WARNING! Do not change this regex without changing do_shortcode_tag() and strip_shortcode_tag()
        // Also, see shortcode_unautop() and shortcode.js.
        return
            '\\['                                // Opening bracket
            . '(\\[?)'                           // 1: Optional second opening bracket for escaping shortcodes: [[tag]]
            . "($tagregexp)"                     // 2: Shortcode name
            . '(?![\\w-])'                       // Not followed by word character or hyphen
            . '('                                // 3: Unroll the loop: Inside the opening shortcode tag
            . '[^\\]\\/]*'                   // Not a closing bracket or forward slash
            . '(?:'
            . '\\/(?!\\])'               // A forward slash not followed by a closing bracket
            . '[^\\]\\/]*'               // Not a closing bracket or forward slash
            . ')*?'
            . ')'
            . '(?:'
            . '(\\/)'                        // 4: Self closing tag ...
            . '\\]'                          // ... and closing bracket
            . '|'
            . '\\]'                          // Closing bracket
            . '(?:'
            . '('                        // 5: Unroll the loop: Optionally, anything between the opening and closing shortcode tags
            . '[^\\[]*+'             // Not an opening bracket
            . '(?:'
            . '\\[(?!\\/\\2\\])' // An opening bracket not followed by the closing shortcode tag
            . '[^\\[]*+'         // Not an opening bracket
            . ')*+'
            . ')'
            . '\\[\\/\\2\\]'             // Closing shortcode tag
            . ')?'
            . ')'
            . '(\\]?)';                          // 6: Optional second closing brocket for escaping shortcodes: [[tag]]
    }
}

/**
 *
 * Tag Regular Expression
 *
 */
if ( !function_exists('reflector_tagregexp') ) {
    function reflector_tagregexp() {
        return apply_filters('reflector_custom_tagregexp', 'video|audio|playlist|video-playlist|embed|cs_media');
    }
}

/**
 *
 * Create custom html structure for comments
 *
 */
if ( !function_exists('reflector_comment') ) {
    function reflector_comment($comment, $args, $depth) {

        $GLOBALS['comment'] = $comment;

        switch ( $comment->comment_type ):
            case 'pingback':
            case 'trackback': ?>
                <p class="pinback">
                    <span class="pin-title"><?php esc_html_e('Pingback:', 'reflector'); ?></span><?php comment_author_link(); ?>
                    <?php edit_comment_link(esc_html__('(Edit)', 'reflector'), '<span class="edit-link">', '</span>'); ?>
                </p>
                <?php
                break;
            default:
                // generate comments
                ?>
                <li <?php comment_class('ct-part'); ?> id="li-comment-<?php comment_ID(); ?>">
                <div id="comment-<?php comment_ID(); ?>">
                    <div class="content">
                        <span class="person-img">
							<?php echo get_avatar($comment, '90', '', '', array('class' => 'img-person')); ?>
                        </span>
                        <div class="comment-content">
                            <div class="person">
                                <div class="author-wrap">
                                    <div class="author">
                                        <?php comment_author(); ?>
                                    </div>
                                    <div class="comment-date">
                                        <?php comment_date(get_option('date_format')); ?>
                                    </div>
                                </div>
                            </div>
                            <?php
                            comment_reply_link(
                                array_merge($args,
                                    array(
                                        'reply_text' => esc_html__('Reply', 'reflector'),
                                        'after'      => '',
                                        'depth'      => $depth,
                                        'max_depth'  => $args['max_depth']
                                    )
                                )
                            ); ?>
                            <div class="text">
                                <?php comment_text(); ?>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
                break;
        endswitch;
    }
}

/*
 * Site logo function.
 */
if ( !function_exists('reflector_site_logo') ) {
    function reflector_site_logo() { ?>

        <a href="<?php echo esc_url(home_url('/')); ?>" class="logo">

            <?php

            $logoScroll = cs_get_option('image_logo_scroll');

            if ( is_404() && cs_get_option('error_logo') ) {
                if ( apply_filters('reflector_type_logo', cs_get_option('error_site_logo')) == 'txtlogo' ) {
                    echo ' <span> ' . esc_html(cs_get_option('error_text_logo')) . '</span>';
                } else {
                    $logo = '';
                    if ( cs_get_option('error_image_logo') ) {
                        $logo = cs_get_option('error_image_logo');
                    }

                    // logo for page
                    ?>
                    <img src="<?php echo esc_url($logo); ?>" alt="<?php echo get_option('blogname'); ?>"
                         class="main-logo">

                    <?php if ( $logoScroll ) { ?>
                        <img src="<?php echo esc_url($logoScroll); ?>" alt="<?php echo get_option('blogname'); ?>"
                             class="logo-hover">
                    <?php } else { ?>
                        <img src="<?php echo esc_url($logo); ?>" alt="<?php echo get_option('blogname'); ?>"
                             class="logo-hover">
                    <?php } ?>
                    <img src="<?php echo esc_url($logo); ?>" alt="<?php echo get_option('blogname'); ?>"
                         class="main-logo logo-mobile">
                    <?php
                }
            } else {

                $meta_data           = get_post_meta(get_the_ID(), '_custom_page_options', true);
                $meta_data_portfolio = get_post_meta(get_the_ID(), 'reflector_portfolio_options', true);
                $meta_data_post = get_post_meta(get_the_ID(), 'reflector_post_options', true);

                $img_logo = false;
                if ( isset($meta_data['image_page_logo']) && !empty($meta_data['image_page_logo']) ) {
                    $img_logo = true;
                } elseif ( isset($meta_data_portfolio['image_page_logo']) && !empty($meta_data_portfolio['image_page_logo']) ) {
                    $img_logo = true;
                }

                $style_header = false;

                if ( isset($meta_data['style_header']) && !empty($meta_data['style_header']) && ($meta_data['style_header'] == 'transparent') ) {
                    $style_header = true;
                } elseif ( isset($meta_data_portfolio['style_header']) && !empty($meta_data_portfolio['style_header']) && ($meta_data_portfolio['style_header'] == 'transparent') ) {
                    $style_header = true;
                }

                if ( cs_get_option('site_logo') == 'imglogo' || $img_logo ) {

                    $logo = cs_get_option('image_logo');

                    // logo for page

                    $logo       = !empty($meta_data['image_page_logo']) ? $meta_data['image_page_logo'] : $logo;
                    $logo       = isset($meta_data_portfolio['image_page_logo']) && !empty($meta_data_portfolio['image_page_logo']) ? $meta_data_portfolio['image_page_logo'] : $logo;
                    $logo       = isset($meta_data_post['image_page_logo']) && !empty($meta_data_post['image_page_logo']) ? $meta_data_post['image_page_logo'] : $logo;
                    $logoScroll = isset($meta_data['image_logo_scroll']) && !empty($meta_data['image_logo_scroll']) ? $meta_data['image_logo_scroll'] : $logoScroll;
                    $logoScroll = isset($meta_data_portfolio['image_logo_scroll']) && !empty($meta_data_portfolio['image_logo_scroll']) ? $meta_data_portfolio['image_logo_scroll'] : $logoScroll;
                    $logoScroll = isset($meta_data_post['image_logo_scroll']) && !empty($meta_data_post['image_logo_scroll']) ? $meta_data_post['image_logo_scroll'] : $logoScroll;
                    $image_logo = apply_filters('reflector_header_logo', $logo);

                    $img_src           = !empty($image_logo) ? $image_logo : REFLECTOR_T_URI . '/assets/images/logo.png';
                    $image_logo_mobile = cs_get_option('image_logo_mobile') ? cs_get_option('image_logo_mobile') : $img_src;
                    $image_logo_mobile = isset($meta_data['image_logo_mobile']) && !empty($meta_data['image_logo_mobile']) ? $meta_data['image_logo_mobile'] : $image_logo_mobile;
                    $image_logo_mobile = isset($meta_data_portfolio['image_logo_mobile']) && !empty($meta_data_portfolio['image_logo_mobile']) ? $meta_data_portfolio['image_logo_mobile'] : $image_logo_mobile;
                    ?>
                    <img src="<?php echo esc_url($img_src); ?>" alt="<?php echo get_option('blogname'); ?>"
                         class="main-logo">

                    <?php if ( $logoScroll && $style_header ) { ?>
                        <img src="<?php echo esc_url($logoScroll); ?>" alt="<?php echo get_option('blogname'); ?>"
                             class="logo-hover">
                    <?php } else { ?>
                        <?php if( $style_header ): ?>
                            <img src="<?php echo esc_url($img_src); ?>" alt="<?php echo get_option('blogname'); ?>"
                                 class="logo-hover">
                        <?php endif; ?>
                    <?php } ?>
                    <img src="<?php echo esc_url($image_logo_mobile); ?>" alt="<?php echo get_option('blogname'); ?>"
                         class="main-logo logo-mobile">
                    <?php

                } elseif ( !function_exists('cs_framework_init') ) {
                    echo '<span>' . get_option('blogname') . '</span>';
                } else {

                    echo '<span>' . esc_html(cs_get_option('text_logo')) . '</span>';
                }
            } ?>
        </a>
    <?php }
}

/*
* Get Page For Navi
*/
if ( !function_exists('reflector_get_pages_for_navi') ) {
    function reflector_get_pages_for_navi() {
        $posts = get_posts("post_type=page&post_status=publish&numberposts=99999&orderby=menu_order");
        $pages = get_page_hierarchy($posts);
        $pages = array_keys($pages);

        return $pages;
    }
}


// Custom row styles for onepage site type+-.
if ( !function_exists('reflector_dynamic_css') ) {
    function reflector_dynamic_css() {
        require_once get_template_directory() . '/assets/css/custom.css.php';
        wp_die();
    }
}
add_action('wp_ajax_nopriv_reflector_dynamic_css', 'reflector_dynamic_css');
add_action('wp_ajax_reflector_dynamic_css', 'reflector_dynamic_css');

/*
* reflector Mini Cart for Woocommerce
*/
if ( !function_exists('reflector_mini_cart') ) {
    function reflector_mini_cart() {

        ob_start();

        if ( class_exists('WooCommerce') ) { ?>

            <div class="reflector_mini_cart">

                <?php do_action( 'woocommerce_before_mini_cart' ); ?>

                <ul class="cart_list product_list_widget">

                    <?php if ( ! WC()->cart->is_empty() ) : ?>

                        <?php foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                            $_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                            $product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

                            if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                                $product_name      = apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key );
                                $product_price     = apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
                                $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );

                                $image_url = wp_get_attachment_image_src( $_product->get_image_id(), 'medium' ); ?>
                                <li class="<?php echo esc_attr( apply_filters( 'woocommerce_mini_cart_item_class', 'mini_cart_item', $cart_item, $cart_item_key ) ); ?>">
                                    <div class="mini_cart_item_thumbnail">
                                        <?php if ( ! $_product->is_visible() && !empty($image_url)) :?>
                                            <img src="<?php echo esc_url($image_url[0]); ?>" alt="<?php echo esc_attr( $product_name ); ?>">
                                        <?php elseif(!empty($image_url)) : ?>
                                            <a href="<?php echo esc_url( $product_permalink ); ?>">
                                                <img src="<?php echo esc_url($image_url[0]); ?>" alt="<?php echo esc_attr( $product_name ); ?>">
                                            </a>
                                        <?php endif; ?>
                                    </div>

                                    <div class="mini-cart-data">
                                        <a href="<?php echo esc_url( $product_permalink ); ?>"
                                           class="mini_cart_item_name">
                                            <?php echo wp_kses_post( $product_name ); ?>
                                        </a>

                                        <div class="mini_cart_item_quantity">
                                            <?php esc_html_e( 'x', 'reflector' ); ?>
                                            <?php echo apply_filters( 'woocommerce_widget_cart_item_quantity', '<span class="quantity">' . $cart_item['quantity'] . '</span>', $cart_item, $cart_item_key ); ?>
                                        </div>

                                        <div class="mini_cart_item_price">
                                            <?php if ( ! empty( $product_price ) ) {
                                                echo wp_kses_post( $product_price );
                                            } ?>
                                        </div>
                                    </div>
                                    <?php
                                    echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf(
                                        '<a href="%s" class="woocommerce-mini-cart__remove remove_from_cart_button" aria-label="%s" data-product_id="%s" data-cart_item_key="%s" data-product_sku="%s">&times;</a>',
                                        esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
                                        esc_html__( 'Remove this item', 'reflector' ),
                                        esc_attr( $product_id ),
                                        esc_attr( $cart_item_key ),
                                        esc_attr( $_product->get_sku() )
                                    ), $cart_item_key );
                                    ?>
                                </li>
                                <?php
                            }
                        }
                        ?>

                    <?php else : ?>

                        <li class="empty"><?php esc_html_e( 'No products in the cart.', 'reflector' ); ?></li>

                    <?php endif; ?>

                </ul><!-- end product list -->

                <div class="reflector-buttons">
                    <a href="<?php echo esc_url(wc_get_cart_url()); ?>"><?php esc_html_e( 'Go to cart', 'reflector' ); ?><i class="fa fa-arrow-right"></i></a>
                    <p class="woocommerce-mini-cart__total total"><?php esc_html_e( 'Total', 'reflector' ); ?>
                        : <?php echo WC()->cart->get_cart_subtotal(); ?></p>
                </div>

            </div>

            <?php
        }

        return ob_get_clean();

    }
}

if ( !function_exists('reflector_include_fonts') ) {
    function reflector_include_fonts($fonts = '') {
        if ( empty($fonts) ) {
            return '';
        }

        if ( !is_array($fonts) ) {
            $fonts = array($name_option);
        }

        foreach ( $fonts as $key => $font ) {
            if ( cs_get_option($font) ) {

                $font_family = cs_get_option($font);
                if ( !empty($font_family['family']) ) {
                    wp_enqueue_style(sanitize_title_with_dashes($font_family['family']), '//fonts.googleapis.com/css?family=' . $font_family['family'] . ':' . $font_family['variant'] . '');
                }
            }
        }

    }
}

// functions max word in string
if ( !function_exists('reflector_maxsite_str_word') ) {
    function reflector_maxsite_str_word($text, $counttext = 10, $sep = ' ') {
        $words = explode($sep, $text);
        if ( count($words) > $counttext ) {
            $text = join($sep, array_slice($words, 0, $counttext));
        }

        return $text;
    }
}


if ( !function_exists('reflector_excerpt_more') ) {
    function reflector_excerpt_more() {
        return ' ...';
    }

    add_filter('excerpt_more', 'reflector_excerpt_more');
}

if ( !function_exists('reflector_search_popup') ) {
    function reflector_search_popup() { ?>
        <div class="site-search" id="search-box-<?php echo esc_attr(rand()); ?>">
            <i class="ion-android-close close-search"></i>
            <div class="form-container">
                <form role="search" method="get" class="search-form" action="<?php echo esc_url(home_url('/')); ?>">
                    <div class="input-group">
                        <input type="search" value="<?php echo get_search_query() ?>" name="s"
                               class="search-field"
                               placeholder="<?php esc_attr_e('Enter search keyword', 'reflector'); ?>"
                               required>
                    </div>
                </form>
            </div>
        </div>
    <?php }
}

add_action('reflector_after_footer', 'reflector_search_popup', 10);


/**
 *
 * Add new fields to user profile.
 *
 */
if ( !function_exists('reflector_show_extra_profile_fields') ) {
    function reflector_show_extra_profile_fields($user) { ?>

        <h3><?php esc_html_e('Extra profile information', 'reflector'); ?></h3>

        <table class="form-table">

            <tr>
                <th><label for="twitter"><?php esc_html_e('Twitter', 'reflector'); ?></label></th>

                <td>
                    <input type="text" name="twitter" id="twitter"
                           value="<?php echo esc_url(get_user_meta($user->ID, 'twitter', true)); ?>"
                           class="regular-text"/><br/>
                    <span class="description"><?php esc_html_e('Please enter your Twitter profile link.', 'reflector'); ?></span>
                </td>
            </tr>
            <tr>
                <th><label for="facebook"><?php esc_html_e('Facebook', 'reflector'); ?></label></th>

                <td>
                    <input type="text" name="facebook" id="facebook"
                           value="<?php echo esc_attr(get_user_meta($user->ID, 'facebook', true)); ?>"
                           class="regular-text"/><br/>
                    <span class="description"><?php esc_html_e('Please enter your Facebook profile link.', 'reflector'); ?></span>
                </td>
            </tr>
            <tr>
                <th><label for="instagram"><?php esc_html_e('Instagram', 'reflector'); ?></label></th>

                <td>
                    <input type="text" name="instagram" id="instagram"
                           value="<?php echo esc_attr(get_user_meta($user->ID, 'instagram', true)); ?>"
                           class="regular-text"/><br/>
                    <span class="description"><?php esc_html_e('Please enter your Instagram profile link.', 'reflector'); ?></span>
                </td>
            </tr>
            <tr>
                <th><label for="dribbble"><?php esc_html_e('Dribbble', 'reflector'); ?></label></th>

                <td>
                    <input type="text" name="dribbble" id="dribbble"
                           value="<?php echo esc_attr(get_user_meta($user->ID, 'dribbble', true)); ?>"
                           class="regular-text"/><br/>
                    <span class="description"><?php esc_html_e('Please enter your Dribbble profile link.', 'reflector'); ?></span>
                </td>
            </tr>

        </table>
    <?php }
}
add_action('show_user_profile', 'reflector_show_extra_profile_fields');
add_action('edit_user_profile', 'reflector_show_extra_profile_fields');

/**
 *
 * Save and update new fields in user profile.
 *
 */
if ( !function_exists('reflector_save_extra_profile_fields') ) {
    function reflector_save_extra_profile_fields($user_id) {

        if ( !current_user_can('edit_user', $user_id) ) {
            return false;
        }
        update_user_meta($user_id, 'facebook', esc_url($_POST['facebook']));
        update_user_meta($user_id, 'twitter', esc_url($_POST['twitter']));
        update_user_meta($user_id, 'instagram', esc_url($_POST['instagram']));
        update_user_meta($user_id, 'dribbble', esc_url($_POST['dribbble']));
    }
}
add_action('personal_options_update', 'reflector_save_extra_profile_fields');
add_action('edit_user_profile_update', 'reflector_save_extra_profile_fields');


/**
 *
 * Menu style
 *
 */

if ( !function_exists('reflector_post_type') ) {
    function reflector_post_type( $post_id, $post_type ) {
        $meta_data = array();
        switch ( $post_type ) {
            case "page":
                $meta_data = get_post_meta( $post_id, '_custom_page_options', true );
                break;
            case "post":
                $meta_data = get_post_meta( $post_id, 'reflector_post_options', true );
                break;
            case "portfolio":
                $meta_data = get_post_meta( $post_id, 'reflector_portfolio_options', true );
                break;
            case "whizzy_proof_gallery":
                $meta_data = get_post_meta( $post_id, 'reflector_whizzy_options', true );
                break;
            case "space":
                $meta_data = get_post_meta( $post_id, 'reflector_space_options', true );
                break;
        }
        return $meta_data;
    }
}

if ( !function_exists('reflector_fixed_header') ) {
    function reflector_fixed_header($menu_main_style, $post_id) {

        $post_type = get_post_type( $post_id );
        $meta_data = reflector_post_type( $post_id, $post_type );
        $fixed_menu_class = is_404() ? ' enable_fixed header_trans-fixed' : '';
        $style_header = isset($meta_data['style_header']) ? $meta_data['style_header'] : '';

        if ( !($menu_main_style == 'static_aside' || $menu_main_style == 'aside' || $menu_main_style == 'bottom') ) {
            if ( isset($style_header) && !empty($style_header) ) {

                switch ( $style_header ) {
                    case "transparent":
                        $fixed_menu_class .= ' header_trans-fixed';
                        break;
                    case "fixed":
                        $fixed_menu_class .= ' fixed-header';
                        break;
                    case "none":
                        $fixed_menu_class .= ' header_trans-fixed none';
                        break;
                    case "empty":
                        $fixed_menu_class .= '';
                        break;
                }
            }
            if ( isset($meta_data['menu_light_text']) && $meta_data['menu_light_text'] ) {
                if ( $style_header == 'transparent' ) {
                    $fixed_menu_class .= ' menu_light_text';
                }
            }
        }

        $fixed_menu_class = !function_exists('cs_framework_init') && is_404() ? ' fixed-header' : $fixed_menu_class;
        $fixed_menu_class = is_tax('portfolio-client') || is_search() || is_tax('portfolio-category') ? '' : $fixed_menu_class;

        return $fixed_menu_class;

    }
}

if ( !function_exists('reflector_main_header_html') ) {
    function reflector_main_header_html() {

        if ( is_page() || is_home() ) {
            $post_id = get_queried_object_id();
        } else {
            $post_id = get_the_ID();
        }

        $post_type = get_post_type( $post_id );

        $meta_data = reflector_post_type( $post_id, $post_type );

        $menu_main_style     = cs_get_option('menu_style') ? cs_get_option('menu_style') : 'simple';
        $menu_main_style     = is_404() ? 'only_logo' : $menu_main_style;

        if ( isset($meta_data['change_menu']) && $meta_data['change_menu'] && isset($meta_data['menu_style']) ) {
            $menu_main_style = $meta_data['menu_style'];
        }

        get_template_part('template-parts/menu/menu', $menu_main_style);

    }
}
add_action('reflector_main_header', 'reflector_main_header_html');

if ( !function_exists('reflector_main_footer_html') ) {
    function reflector_main_footer_html() {

        if ( is_page() || is_home() ) {
            $post_id = get_queried_object_id();
        } else {
            $post_id = get_the_ID();
        }

        $post_type = get_post_type( $post_id );
        $meta_data = reflector_post_type( $post_id, $post_type );

        $reflector_footer_style = cs_get_option('reflector_footer_style') ? cs_get_option('reflector_footer_style') : 'simple';

        if ( isset($meta_data['reflector_footer_style']) && $meta_data['reflector_footer_style'] ) {
            $reflector_footer_style = $meta_data['reflector_footer_style'];
        }

        get_template_part('template-parts/footer/footer', $reflector_footer_style);
    }
}
add_action('reflector_main_footer', 'reflector_main_footer_html');

if ( !function_exists('reflector_portfolio_pagination') ) {
    function reflector_portfolio_pagination() { ?>
        <div class="single-pagination-portfolio">
            <div class="container">
                <div class="row">
                    <div class="col-12">
                        <div class="single-pagination-wrap">
                            <?php
                            $prev_post = get_previous_post(); ?>
                            <div class="page-control pag-prev">
                                <?php if ( !empty($prev_post) ) : ?>
                                    <i class="fas fa-angle-left"></i>
                                    <div>
                                        <a href="<?php echo esc_url(get_permalink($prev_post->ID)); ?>"><?php esc_html_e('Prev project', 'reflector'); ?></a>
                                    </div>
                                    <a href="<?php echo esc_url(get_permalink($prev_post->ID)); ?>"
                                       class="content"><?php echo get_the_title($prev_post); ?></a>
                                <?php endif; ?>
                            </div>
                            <div class="pag-separate"></div>
                            <?php $next_post = get_next_post(); ?>
                            <div class="page-control pag-next">
                                <?php if ( !empty($next_post) ) : ?>
                                    <div>
                                        <a href="<?php echo esc_url(get_permalink($next_post->ID)); ?>"><?php esc_html_e('Next project', 'reflector'); ?></a>
                                    </div>
                                    <a href="<?php echo esc_url(get_permalink($next_post->ID)); ?>"
                                       class="content"><?php echo get_the_title($next_post); ?></a>
                                    <i class="fas fa-angle-right"></i>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    <?php }
}