<?php
/*
 * Single Blog post
 */


$protected = '';

if ( post_password_required() ) {
	$protected = 'protected-page';
}
$cs_sidebar = cs_get_option( 'sidebar' );

$get_id           = get_the_ID();
$post_meta        = get_post_meta( $get_id, 'reflector_post_options', true );
$sidebar_position = isset( $post_meta['sidebar_position'] ) ? $post_meta['sidebar_position'] : 'right';

$content_size_class = ( ( ! function_exists( 'cs_framework_init' ) && is_active_sidebar( 'sidebar' ) ) || ( $cs_sidebar && in_array( 'post', $cs_sidebar ) ) ) && $sidebar_position !== 'none' ? 'col-lg-8' : 'col-lg-12';
$sidebar_class      = $content_size_class == 'col-lg-8' ? 'sidebar-show' : 'sidebar-no';

$tags        = get_the_tags();
$show_tags   = cs_get_option( 'reflector_post_tags' ) ? true : false;
$enable_tags = isset( $tags ) && ! empty( $tags ) ? true : false;

$show_cats   = cs_get_option( 'reflector_post_cat' ) ? true : false;
$enable_cats = get_the_category();

$post_show_cats = count( $enable_cats ) !== 0 && ( $show_cats || ! function_exists( 'cs_framework_init' ) ) ? true : false;
$post_show_tags = $enable_tags && ( ! function_exists( 'cs_framework_init' ) || $show_tags ) ? true : false; ?>

<div class="post-wrapper <?php echo esc_attr( $protected ); ?>">
    <div class="container">
        <div class="row post-details">
			<?php if ( $sidebar_class == 'sidebar-show' && $sidebar_position == 'left' ) {
				wp_enqueue_style( 'sidebar', REFLECTOR_T_URI . '/assets/css/blog/sidebar.css' ); ?>
                <div class="col-12 col-lg-4">
                    <div class="sidebar">
                        <?php if ( ! function_exists( 'dynamic_sidebar' ) || ! dynamic_sidebar( 'sidebar' ) ) ?>
                    </div>
                </div>
				<?php } ?>
            <div class="col-12 <?php echo esc_attr( $content_size_class ); ?>">
                <div class="single-content">
                    <div class="main-top-content">
						<?php the_title( '<h2 class="title">', '</h2>' ); ?>
                        <div class="date-post"><?php the_time( get_option( 'date_format' ) ); ?></div>
                    </div>

					<?php if ( has_post_thumbnail() ) { ?>
                        <div class="post-banner">
							<?php $image_url = get_the_post_thumbnail_url( $get_id, 'full' );
							$image_id        = get_post_thumbnail_id( $get_id );
							$image_alt       = get_post_meta( $image_id, '_wp_attachment_image_alt', true ); ?>

                            <img src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( $image_alt ); ?>">

                        </div>
					<?php } ?>

                    <div class="single-content-wrapper">

						<?php the_content();
						wp_link_pages( 'link_before=<span class="pages">&link_after=</span>&before=<div class="post-nav"> <span>' . esc_html__( "Page:", 'reflector' ) . ' </span> &after=</div>' ); ?>

                    </div>
					<?php if ( $post_show_cats || $post_show_tags ) { ?>
                        <div class="post-info-wrapper">
							<?php if ( $post_show_tags ) { ?>
                                <div class="single-tags">
                                    <span><?php esc_html_e( 'Tags: ', 'reflector' ); ?></span>
									<?php the_tags( '', ', ' ); ?>
                                </div>
							<?php } ?>

							<?php if ( $post_show_cats ) { ?>
                                <div class="single-categories">
                                    <span><?php esc_html_e( 'Categories: ', 'reflector' ); ?></span>
									<?php the_category( ', ' ); ?>
                                </div>
							<?php } ?>
                        </div>
					<?php }

					if ( comments_open() || '0' != get_comments_number() && wp_count_comments( $get_id ) ) { ?>
                        <ul class="comments main">
							<?php comments_template( '', true ); ?>
                        </ul>
					<?php } ?>

                    <div class="single-post-pagination">
                        <div class="pag-prev">
							<?php $prev_post     = get_previous_post();
							if ( ! empty( $prev_post ) ) :
								$prev_thumbnail = get_the_post_thumbnail_url( $prev_post->ID, 'thumbnail' );
								$prev_post_title = ! empty( get_the_title( $prev_post ) ) ? get_the_title( $prev_post ) : esc_html__( 'No title', 'reflector' );
								$prev_link       = get_permalink( $prev_post ); ?>


								<?php if ( ! empty( $prev_thumbnail ) ) { ?>
                                <a href="<?php echo esc_url( $prev_link ); ?>" class="img-wrap">
                                    <img src="<?php echo esc_url( $prev_thumbnail ); ?>"
                                         alt="<?php echo esc_attr( $prev_post_title ); ?>">
                                </a>
							<?php } ?>
                                <span>
                                    <?php esc_html_e( 'Previous post', 'reflector' ); ?>
                                    <a href="<?php echo esc_url( $prev_link ); ?>" class="content">
                                        <?php echo wp_kses_post( $prev_post_title ); ?>
                                    </a>
                                </span>


							<?php endif; ?>
                        </div>

						<?php $next_post = get_next_post(); ?>
                        <div class="pag-next">
							<?php if ( ! empty( $next_post ) ) :
								$next_thumbnail = get_the_post_thumbnail_url( $next_post->ID, 'thumbnail' );
								$next_post_title = ! empty( get_the_title( $next_post ) ) ? get_the_title( $next_post ) : esc_html__( 'No title', 'reflector' );
								$next_link = get_permalink( $next_post ); ?>


								<?php if ( ! empty( $next_thumbnail ) ) { ?>
                                <a href="<?php echo esc_url( $next_link ); ?>" class="img-wrap">
                                    <img src="<?php echo esc_url( $next_thumbnail ); ?>"
                                         alt="<?php echo esc_attr( $next_post_title ); ?>">
                                </a>
							<?php } ?>
                                <span>
                                        <?php esc_html_e( 'Next post', 'reflector' ); ?>
                                    <a href="<?php echo esc_url( $next_link ); ?>" class="content">
                                            <?php echo wp_kses_post( $next_post_title ); ?>
                                        </a>
                                    </span>

							<?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
			<?php if ( $sidebar_class == 'sidebar-show' && $sidebar_position == 'right' ) {
				wp_enqueue_style( 'sidebar', REFLECTOR_T_URI . '/assets/css/blog/sidebar.css' ); ?>
                <div class="col-12 col-lg-4">
                <div class="sidebar">
				<?php if ( ! function_exists( 'dynamic_sidebar' ) || ! dynamic_sidebar( 'sidebar' ) ) ?>
                    </div>
                    </div>
				<?php } ?>
        </div>
    </div>
</div>